/*******************************************************************************

  Copyright(c) 1999 - 2015 Intel Corporation. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify it 
  under the terms of the GNU General Public License as published by the Free 
  Software Foundation; either version 2 of the License, or (at your option) 
  any later version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
  more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 59 
  Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
  The full GNU General Public License is included in this distribution in the
  file called LICENSE.
  
  Contact Information:
  e1000 mailing list <e1000-devel@lists.sourceforge.net>
  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497

*******************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include <getopt.h>
#include <sys/mman.h>
#include <sys/types.h>
#include "ethregs.h"
#include "ethregs-config.h"


#define min(x,y) ({ \
	typeof(x) _x = (x);\
	typeof(y) _y = (y);\
	(void) (&_x == &_y);\
	_x < _y ? _x : _y; })

#define E1000_MAX_REG_OFFSET	0x20000
#define E1000_VF_REG_OFFSET	0x4000
#define IXGBE_MAX_REG_OFFSET	0x1FFFC
#define FM10K_MAX_REG_OFFSET	0xFFFFF
#define I40E_MAX_REG_OFFSET		0x0400000

static struct pci_filter filter;	/* Device filter */
static int dev_mem_fd;
int clr = 0;
int offset = 0;

static struct option opts[] = {
	{"clear", 0, NULL, 'c' },
	{"debug", 0, NULL, 'D' },
	{"idfile", 1, NULL, 'i' },
	{"offset", 0, NULL, 'o' },
	{"version", 0, NULL, 'V' },
	{"device", 1, NULL, 'd' },
	{"slot", 1, NULL, 's' },
	{ 0, 0, NULL, '0' }
};

static void usage(char *progname, char *idfile)
{
	printf("%s: version %s\n", progname, PACKAGE_VERSION);
	printf(	"Usage: %s [options] [device]\n\n"
		"Options:\n"
		"-c\t\tDisplay registers that are cleared on read\n"
		"-D\t\tPCI debugging\n"
		"-i <file>\tUse specified ID database instead of %s\n"
		"-o\t\tDisplay register offset\n"
#ifdef HAVE_PCI_FIND_CAP
		"-m\t\tDisplay MSI-X Table Registers\n"
#endif
		"-V\t\tDisplay version\n"
		"Device:\n"
		"-d [<vendor>]:[<device>]\t\t\tShow selected devices\n"
		"-s [[[[<domain>]:]<bus>]:][<slot>][.[<func>]]"
			"\tShow devices in selected slots\n\n",
		progname, idfile);
}

static void get_eth_device_info(u16 device_id, struct eth_device_info *eth_info)
{
	switch (device_id) {
	case E1000_DEV_ID_82542:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_82542;
		break;
	case E1000_DEV_ID_82543GC_FIBER:
	case E1000_DEV_ID_82543GC_COPPER:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_82543;
		break;
	case E1000_DEV_ID_82544EI_COPPER:
	case E1000_DEV_ID_82544EI_FIBER:
	case E1000_DEV_ID_82544GC_COPPER:
	case E1000_DEV_ID_82544GC_LOM:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_82544;
		break;
	case E1000_DEV_ID_82540EM:
	case E1000_DEV_ID_82540EM_LOM:
	case E1000_DEV_ID_82540EP_LOM:
	case E1000_DEV_ID_82540EP:
	case E1000_DEV_ID_82540EP_LP:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_82540;
		break;
	case E1000_DEV_ID_82541EI:
	case E1000_DEV_ID_82541EI_MOBILE:
	case E1000_DEV_ID_82541ER_LOM:
	case E1000_DEV_ID_82541ER:
	case E1000_DEV_ID_82541GI:
	case E1000_DEV_ID_82541GI_MOBILE:
	case E1000_DEV_ID_82541GI_LF:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_82541;
		break;
	case E1000_DEV_ID_82545EM_COPPER:
	case E1000_DEV_ID_82545EM_FIBER:
	case E1000_DEV_ID_82545GM_COPPER:
	case E1000_DEV_ID_82545GM_FIBER:
	case E1000_DEV_ID_82545GM_SERDES:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_82545;
		break;
	case E1000_DEV_ID_82546EB_COPPER:
	case E1000_DEV_ID_82546EB_FIBER:
	case E1000_DEV_ID_82546EB_QUAD_COPPER:
	case E1000_DEV_ID_82546GB_COPPER:
	case E1000_DEV_ID_82546GB_FIBER:
	case E1000_DEV_ID_82546GB_SERDES:
	case E1000_DEV_ID_82546GB_PCIE:
	case E1000_DEV_ID_82546GB_QUAD_COPPER_KSP3:
	case E1000_DEV_ID_82546GB_QUAD_COPPER:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_82546;
		break;
	case E1000_DEV_ID_82547EI:
	case E1000_DEV_ID_82547EI_MOBILE:
	case E1000_DEV_ID_82547GI:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_82547;
		break;
	case E1000_DEV_ID_82571EB_COPPER:
	case E1000_DEV_ID_82571EB_FIBER:
	case E1000_DEV_ID_82571EB_SERDES:
	case E1000_DEV_ID_82571EB_QUAD_COPPER:
	case E1000_DEV_ID_82571EB_QUAD_FIBER:
	case E1000_DEV_ID_82571EB_QUAD_COPPER_LP:
	case E1000_DEV_ID_82571EB_SERDES_DUAL:
	case E1000_DEV_ID_82571EB_SERDES_QUAD:
	case E1000_DEV_ID_82571PT_QUAD_COPPER:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_82571;
		break;
	case E1000_DEV_ID_82572EI_COPPER:
	case E1000_DEV_ID_82572EI_FIBER:
	case E1000_DEV_ID_82572EI_SERDES:
	case E1000_DEV_ID_82572EI:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_82572;
		break;
	case E1000_DEV_ID_82573E:
	case E1000_DEV_ID_82573E_IAMT:
	case E1000_DEV_ID_82573L:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_82573;
		break;
	case E1000_DEV_ID_82574L:
	case E1000_DEV_ID_82574LA:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_82574;
		break;
	case E1000_DEV_ID_82583V:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_82583;
		break;
	case E1000_DEV_ID_80003ES2LAN_COPPER_DPT:
	case E1000_DEV_ID_80003ES2LAN_SERDES_DPT:
	case E1000_DEV_ID_80003ES2LAN_COPPER_SPT:
	case E1000_DEV_ID_80003ES2LAN_SERDES_SPT:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_80003es2lan;
		break;
	case E1000_DEV_ID_ICH8_IGP_M_AMT:
	case E1000_DEV_ID_ICH8_IGP_AMT:
	case E1000_DEV_ID_ICH8_IGP_C:
	case E1000_DEV_ID_ICH8_IFE:
	case E1000_DEV_ID_ICH8_IFE_GT:
	case E1000_DEV_ID_ICH8_IFE_G:
	case E1000_DEV_ID_ICH8_IGP_M:
	case E1000_DEV_ID_ICH8_82567V_3:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_ich8lan;
		break;
	case E1000_DEV_ID_ICH9_IGP_C:
	case E1000_DEV_ID_ICH9_IGP_M:
	case E1000_DEV_ID_ICH9_IGP_M_AMT:
	case E1000_DEV_ID_ICH9_IGP_M_V:
	case E1000_DEV_ID_ICH9_IGP_AMT:
	case E1000_DEV_ID_ICH9_BM:
	case E1000_DEV_ID_ICH9_IFE:
	case E1000_DEV_ID_ICH9_IFE_GT:
	case E1000_DEV_ID_ICH9_IFE_G:
	case E1000_DEV_ID_ICH10_R_BM_LM:
	case E1000_DEV_ID_ICH10_R_BM_LF:
	case E1000_DEV_ID_ICH10_R_BM_V:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_ich9lan;
		break;
	case E1000_DEV_ID_ICH10_D_BM_LM:
	case E1000_DEV_ID_ICH10_D_BM_LF:
	case E1000_DEV_ID_ICH10_D_BM_V:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_ich10lan;
		break;
	case E1000_DEV_ID_PCH_M_HV_LM:
	case E1000_DEV_ID_PCH_M_HV_LC:
	case E1000_DEV_ID_PCH_D_HV_DM:
	case E1000_DEV_ID_PCH_D_HV_DC:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_pchlan;
		break;
	case E1000_DEV_ID_PCH2_LV_LM:
	case E1000_DEV_ID_PCH2_LV_V:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_pch2lan;
		break;
	case E1000_DEV_ID_PCH_LPT_I217_LM:
	case E1000_DEV_ID_PCH_LPT_I217_V:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_pch_lpt;
		break;
	case E1000_DEV_ID_82575EB_FIBER_SERDES:
	case E1000_DEV_ID_82575GB_QUAD_COPPER:
	case E1000_DEV_ID_82575EB_COPPER:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_82575;
		break;
	case E1000_DEV_ID_82576:
	case E1000_DEV_ID_82576_NS:
	case E1000_DEV_ID_82576_NS_SERDES:
	case E1000_DEV_ID_82576_FIBER:
	case E1000_DEV_ID_82576_SERDES:
	case E1000_DEV_ID_82576_SERDES_QUAD:
	case E1000_DEV_ID_82576_QUAD_COPPER:
	case E1000_DEV_ID_82576_QUAD_COPPER_ET2:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_82576;
		break;
	case E1000_DEV_ID_82576_VF:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_vfadapt;
	break;
	case E1000_DEV_ID_82580_COPPER:
	case E1000_DEV_ID_82580_FIBER:
	case E1000_DEV_ID_82580_SERDES:
	case E1000_DEV_ID_82580_SGMII:
	case E1000_DEV_ID_82580_COPPER_DUAL:
	case E1000_DEV_ID_82580_QUAD_FIBER:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_82580;
		break;
	case E1000_DEV_ID_I350_COPPER:
	case E1000_DEV_ID_I350_FIBER:
	case E1000_DEV_ID_I350_SERDES:
	case E1000_DEV_ID_I350_SGMII:
	case E1000_DEV_ID_I350_DA4:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_i350;
		break;
	case E1000_DEV_ID_I354_BACKPLANE_1GBPS:
	case E1000_DEV_ID_I354_SGMII:
	case E1000_DEV_ID_I354_BACKPLANE_2_5GBPS:
		eth_info->device_type = e1000_device;
		eth_info->mac_type = e1000_i354;
		break;
	case IXGBE_DEV_ID_82598:
	case IXGBE_DEV_ID_82598_BX:
	case IXGBE_DEV_ID_82598AF_DUAL_PORT:
	case IXGBE_DEV_ID_82598AF_SINGLE_PORT:
	case IXGBE_DEV_ID_82598AT:
	case IXGBE_DEV_ID_82598AT2:
	case IXGBE_DEV_ID_82598EB_CX4:
	case IXGBE_DEV_ID_82598_CX4_DUAL_PORT:
	case IXGBE_DEV_ID_82598_DA_DUAL_PORT:
	case IXGBE_DEV_ID_82598_SR_DUAL_PORT_EM:
	case IXGBE_DEV_ID_82598EB_XF_LR:
	case IXGBE_DEV_ID_82598EB_SFP_LOM:
		eth_info->device_type = ixgbe_device;
		eth_info->mac_type = ixgbe_mac_82598EB;
		break;
	case IXGBE_DEV_ID_82599_KX4:
	case IXGBE_DEV_ID_82599_SFP:
	case IXGBE_DEV_ID_82599_SFP_EM:
	case IXGBE_DEV_ID_82599_SFP_SF2:
	case IXGBE_DEV_ID_82599_XAUI_LOM:
	case IXGBE_DEV_ID_82599_KX4_MEZZ:
	case IXGBE_DEV_ID_82599_CX4:
	case IXGBE_DEV_ID_82599_COMBO_BACKPLANE:
	case IXGBE_DEV_ID_82599_KR:
	case IXGBE_DEV_ID_82599_T3_LOM:
	case IXGBE_DEV_ID_82599_BACKPLANE_FCOE:
	case IXGBE_DEV_ID_82599_SFP_FCOE:
	case IXGBE_DEV_ID_82599_LS:
	case IXGBE_DEV_ID_82599EN_SFP:
	case IXGBE_DEV_ID_82599_SFP_SF_QP:
		eth_info->device_type = ixgbe_device;
		eth_info->mac_type = ixgbe_mac_82599EB;
		break;
	case IXGBE_DEV_ID_82599_VF:
		eth_info->device_type = ixgbe_device;
		eth_info->mac_type = ixgbe_mac_82599_vf;
		break;
	case IXGBE_DEV_ID_X540T:
		eth_info->device_type = ixgbe_device;
		eth_info->mac_type = ixgbe_mac_X540;
		break;
	case IXGBE_DEV_ID_X540_VF:
		eth_info->device_type = ixgbe_device;
		eth_info->mac_type = ixgbe_mac_X540_vf;
		break;
		break;
	case FM10K_DEV_ID_PF:
		eth_info->device_type = fm10k_device;
		eth_info->mac_type = fm10k_mac_pf;
		break;
	case FM10K_DEV_ID_VF:
		eth_info->device_type = fm10k_device;
		eth_info->mac_type = fm10k_mac_vf;
		break;
	case I40E_DEV_ID_SFP_XL710:
	case I40E_DEV_ID_QEMU:
	case I40E_DEV_ID_KX_A:
	case I40E_DEV_ID_KX_B:
	case I40E_DEV_ID_KX_C:
	case I40E_DEV_ID_QSFP_A:
	case I40E_DEV_ID_QSFP_B:
	case I40E_DEV_ID_QSFP_C:
	case I40E_DEV_ID_10G_BASE_T:
	case I40E_DEV_ID_20G_KR2:
	case I40E_DEV_ID_20G_KR2_A:
	case I40E_DEV_ID_10G_BASE_T4:
		eth_info->device_type = i40e_device;
		eth_info->mac_type = I40E_MAC_XL710;
		break;
	default:
		eth_info->device_type = eth_device_unknown;
		eth_info->mac_type = 0;
		break;
	}
}

static int dump_registers(struct pci_dev *dev, struct eth_device_info *eth_info)
{
	volatile void *mem;
	u32 size = 0;

	switch (eth_info->device_type) {
	case e1000_device:
		if (eth_info->mac_type == e1000_vfadapt)
			size = E1000_VF_REG_OFFSET;
		else
			size = E1000_MAX_REG_OFFSET;
		break;

	case ixgbe_device:
		if (eth_info->mac_type == ixgbe_mac_82599_vf)
			size = E1000_MAX_REG_OFFSET;
		else
			size = IXGBE_MAX_REG_OFFSET;
		break;
	case fm10k_device:
		size = FM10K_MAX_REG_OFFSET;
		break;

	case i40e_device:
		size = I40E_MAX_REG_OFFSET;
		break;

	default:
		break;
	}

	if ((dev->known_fields & PCI_FILL_SIZES) &&
	    (size > dev->size[0]))
		size = dev->size[0];

	if ((size == 0) || (dev->base_addr[0] & PCI_BASE_ADDRESS_SPACE_IO) ||
			((dev->base_addr[0] & PCI_ADDR_MEM_MASK) % getpagesize()))
		return -1;

	mem = mmap(NULL, size, PROT_READ, MAP_SHARED, dev_mem_fd,
			(dev->base_addr[0] & PCI_ADDR_MEM_MASK));
	if (mem == MAP_FAILED) {
		perror("mmap - try rebooting with iomem=relaxed");
		return -1;
	}

	printf(	"\t%sName                  Value\n\t%s~~~~                  ~~~~~\n",
			(offset ? "Offset    " : ""), (offset ? "~~~~~~    " : ""));

	switch (eth_info->device_type) {
	case e1000_device:

		switch (eth_info->mac_type) {
		case e1000_82542:
			dump_82542_registers(mem, size);
			break;
		case e1000_82540:
		case e1000_82541:
		case e1000_82541_rev_2:
		case e1000_82543:
		case e1000_82544:
		case e1000_82545:
		case e1000_82545_rev_3:
		case e1000_82546:
		case e1000_82546_rev_3:
		case e1000_82547:
		case e1000_82547_rev_2:
			dump_8254x_registers(mem, size, eth_info->mac_type);
			break;
		case e1000_82571:
		case e1000_82572:
		case e1000_82573:
		case e1000_82574:
		case e1000_82583:
			dump_8257x_registers(mem, size, eth_info->mac_type);
			break;
		case e1000_80003es2lan:
			dump_80003es2lan_registers(mem, size);
			break;
		case e1000_ich8lan:
		case e1000_ich9lan:
		case e1000_ich10lan:
		case e1000_pchlan:
		case e1000_pch2lan:
		case e1000_pch_lpt:
			dump_ichlan_registers(mem, size, eth_info->mac_type);
			break;
		case e1000_82575:
			dump_82575_registers(mem, size);
			break;
		case e1000_82576:
		case e1000_82580:
			dump_82576_registers(mem, size);
			break;
		case e1000_i350:
		case e1000_i354:
			dump_I350_registers(mem, size);
			break;
		case e1000_vfadapt:
			dump_82576vf_registers(mem, size);
			break;
		case e1000_undefined:
		case e1000_num_macs:
			break;
		} /* switch (eth_info->mac_type) */
		break;
	case ixgbe_device:
		switch (eth_info->mac_type) {
		case ixgbe_mac_82598EB:
			dump_82598_registers(mem, size);
			break;
		case ixgbe_mac_82599EB:
			dump_82599_registers(mem, size);
			break;
		case ixgbe_mac_82599_vf:
			dump_82599vf_registers(mem, size);
			break;
		case ixgbe_mac_X540:
			dump_X540_registers(mem, size);
			break;
		case ixgbe_mac_X540_vf:
			dump_X540vf_registers(mem, size);
			break;
		case ixgbe_mac_unknown:
		case ixgbe_num_macs:
			break;
		} /* switch (eth_info->mac_type) */
		break;
	case fm10k_device:
		switch (eth_info->mac_type) {
		case fm10k_mac_pf:
			dump_fm10kpf_registers(mem, size);
			break;
		case fm10k_mac_vf:
			dump_fm10kvf_registers(mem, size);
			break;
		}
		break;
	case i40e_device:
		dump_i40epf_registers(mem, size);
		break;
	case eth_device_unknown:
	case eth_device_max:
		break;
	} /* switch (eth_info->device_type) */

	if (munmap((void *)mem, size) < 0) {
		perror("munmap");
		return -1;
	}
	printf("\n\n");
	return 0;
}

#ifdef HAVE_PCI_FIND_CAP
static int dump_msix_registers(struct pci_dev *dev)
{
	struct pci_cap *msix_cap;
	volatile void *mem;
	u32 bir = 0, offset = 0;
	u16 size, i;

	msix_cap = pci_find_cap(dev, PCI_CAP_ID_MSIX, PCI_CAP_NORMAL);

	/* no MSI-X capabilities found, just exit without error */
	if (!msix_cap)
		return 0;

	size = pci_read_word(dev, msix_cap->addr + 2);
	size &= PCI_MSIX_TABSIZE;
	if (!size || size > 256)
		return -1;

	/* add 1 since table size is actually size + 1 */
	size++;

	/* dump MSI-X vector table */
	bir = pci_read_long(dev, msix_cap->addr + 4);
	if (!bir)
		return -1;
	if (bir > 7) {
		offset = bir & ~0x7;
		bir &= 0x7;
	}	

	mem = mmap(NULL, (size * 16) + offset, PROT_READ, MAP_SHARED,
	           dev_mem_fd, (dev->base_addr[bir] & PCI_ADDR_MEM_MASK));

	if (mem == MAP_FAILED) {
		perror("mmap - try rebooting with iomem=relaxed");
		return -1;
	}

	printf("\tVector Control \tMessage Data \tMessage Address\n");
	for (i = 0; i < size; i++) {
		printf("\t0x%08X \t0x%08X \t0x%08X%08X\n",
		       *(u32 *)(mem + offset + (i * 16) + 12),
		       *(u32 *)(mem + offset + (i * 16) + 8),
		       *(u32 *)(mem + offset + (i * 16) + 4),
		       *(u32 *)(mem + offset + (i * 16)));
	}
		
	if (munmap((void *)mem, size) < 0) {
		perror("munmap");
		return -1;
	}

	/* dump MSI-X pending bit array */
	bir = pci_read_long(dev, msix_cap->addr + 8);
	if (!bir)
		return -1;
	if (bir > 7) {
		offset = bir & ~0x7;
		bir &= 0x7;
	}	

	mem = mmap(NULL, ((size + 31)/32) + offset, PROT_READ, MAP_SHARED,
	           dev_mem_fd, (dev->base_addr[bir] & PCI_ADDR_MEM_MASK));

	if (mem == MAP_FAILED) {
		perror("mmap - try rebooting with iomem=relaxed");
		return -1;
	}

	printf("\n\tPending Bit Array\n");
	for (i = 0; i < ((size + 31)/32); i++) {
		printf("\t0x%08X\n",
		       *(u32 *)(mem + offset + (i * 4)));
	}
	
	if (munmap((void *)mem, size) < 0) {
		perror("munmap");
		return -1;
	}

	printf("\n\n");
	return 0;
}

#endif /* HAVE_PCI_FIND_CAP */
int main(int argc, char **argv)
{
	int ch;
	struct pci_access *pacc;
	struct pci_dev *dev;
	char *errmsg;
	char buf[128];
	int ret;
	struct eth_device_info eth_info;
#ifdef HAVE_PCI_FIND_CAP
	int msix = 0;
#endif /* HAVE_PCI_FIND_CAP */


	if (getuid() != 0) {
		printf("%s: must be run as root\n", argv[0]);
		exit(1);
	}

	dev_mem_fd = open("/dev/mem", O_RDONLY);
	if (dev_mem_fd < 0) {
			perror("open");
			exit(1);
	}

	pacc = pci_alloc();		/* Get the pci_access structure */
	if (pacc == NULL) {
		perror("pci_alloc");
		exit(1);
	}
	pci_filter_init(pacc, &filter);

	while ((ch = getopt_long(argc, argv, "cDi:omVd:s:", opts, NULL)) != -1) {
		switch (ch) {
		case 'c':
			clr = 1;
			break;
		case 'D':
			pacc->debugging++;
			break;
		case 'i':
			pacc->id_file_name = optarg;
			break;
		case 'o':
			offset = 1;
			break;
#ifdef HAVE_PCI_FIND_CAP
		case 'm':
			msix = 1;
			break;
#endif /* HAVE_PCI_FIND_CAP */
		case 'V':
			printf("%s - version %s\n", argv[0], PACKAGE_VERSION);
			exit(0);
			break;
		case 'd':
			/* Show only selected devices */
			if ((errmsg = pci_filter_parse_id(&filter, optarg))) {
				printf("%s\n", errmsg);
				exit(1);
			}
			if ((filter.vendor >= 0) &&
				(filter.vendor != PCI_VENDOR_ID_INTEL)) {
				printf("Only Intel devices are supported!\n");
				exit(1);
			}
			break;
		case 's':
			/* Show only devices in selected slots */
			if ((errmsg = pci_filter_parse_slot(&filter, optarg))) {
				printf("%s\n", errmsg);
				exit(1);
			}
			break;
		case '?':
		default:
			usage(argv[0], pacc->id_file_name);
			exit(1);
			break;
		}
	}

	pci_init(pacc);			/* Initialize the PCI library */
	pci_scan_bus(pacc);		/* Get the list of devices */

	filter.vendor = PCI_VENDOR_ID_INTEL;	/* only interested in Intel stuff */

	if (pacc->debugging)
		printf(	"filter: "
#ifdef HAVE_DOMAIN_SUPPORT
			"domain=0x%x "
#endif /* HAVE_DOMAIN_SUPPORT */
			"bus=0x%x slot=0x%x func=0x%x\n"
			"\tvendor=0x%x device=0x%x\n\n",
#ifdef HAVE_DOMAIN_SUPPORT
			filter.domain,
#endif /* HAVE_DOMAIN_SUPPORT */
			filter.bus, filter.slot, filter.func,
			filter.vendor, filter.device);

	/* Iterate over all devices */
	for (dev = pacc->devices; dev; dev = dev->next)
	{
		if (!pci_filter_match(&filter, dev))
			continue;

		/* skip non-ethernet adapters */
		if (pci_read_word(dev, PCI_CLASS_DEVICE) != PCI_CLASS_NETWORK_ETHERNET)
			continue;

		/* Fill in header info we need */
		pci_fill_info(dev, PCI_FILL_IDENT | PCI_FILL_BASES | PCI_FILL_SIZES);

		get_eth_device_info(dev->device_id, &eth_info);
		if (eth_info.device_type == eth_device_unknown) {
			printf("Unknown device id = 0x%4.4x\n", dev->device_id);
		 	continue;
		}

#ifdef HAVE_DOMAIN_SUPPORT
		if (dev->domain)
			printf("%04x:", dev->domain);
#endif /* HAVE_DOMAIN_SUPPORT */
		printf(	"%02x:%02x.%d (%04x:%04x)\n%s\n",
				dev->bus, dev->dev, dev->func, 
				dev->vendor_id, dev->device_id,
				pci_lookup_name(pacc, buf, sizeof(buf),
					PCI_LOOKUP_VENDOR|PCI_LOOKUP_DEVICE, 
					dev->vendor_id, dev->device_id, 0, 0));

		/* dump out the registers */
		ret = dump_registers(dev, &eth_info);
		if (ret) {
			printf("dump_registers() returns %d\n", ret);
			goto out;
		}

#ifdef HAVE_PCI_FIND_CAP
		/* dump out the MSI-X table registers */
		if (msix && (ret = dump_msix_registers(dev))) {
			printf("dump_msix_registers() returns %d\n", ret);
			goto out;
		}
#endif /* HAVE_PCI_FIND_CAP */
	}

out:
	pci_cleanup(pacc);		/* Close everything */
	return 0;
}

// vi:ts=4:sw=4:ht=4:
