/*******************************************************************************

  Copyright(c) 1999 - 2015 Intel Corporation. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify it 
  under the terms of the GNU General Public License as published by the Free 
  Software Foundation; either version 2 of the License, or (at your option) 
  any later version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
  more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 59 
  Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
  The full GNU General Public License is included in this distribution in the
  file called LICENSE.
  
  Contact Information:
  e1000 mailing list <e1000-devel@lists.sourceforge.net>
  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497

*******************************************************************************/

#include <stdio.h>
#include "ethregs.h"


extern int clr;
extern int offset;

void dump_i40epf_registers(volatile void *mem, u32 size)
{
	u32 i;
	char name[80];

	for (i = 0; i < size; i += sizeof(u32)) {
		switch (i & 0xffffffff) {
		/*
		 * the following case statements can be generated by running
		 * the this vim colon command:
		 *
:r !cat SHARED_I40E/i40e_register.h | sed -e 's/if\(.*EXTERNAL_RELEASE.*\)/ifndef EXTERNAL_RELEASE/' | unifdef -DEXTERNAL_RELEASE -UFORTVILLE_A0_SUPPORT -UFORTPARK_SUPPORT | egrep "0x00[0-9ABCDEF]+" | grep -v 0x00000000 | grep -v I40E_VF | sed -e 's/([^,]\+)/(0)/' -e 's/(.*, .*)/(0,0)/' -e 's/\$//' -e 's/I40E_//' | awk '{ printf "\t\tcase I40E_\%s:\n\t\t\tsprintf(name, \"\%s\"); break;\n", $2, $2 }'
		 *
		 * There may be a few registers that don't compile correctly, so
		 * expect a little bit of hand tweaking once you've updated the list.
		 *
		 * These are deadbeef registers that shouldn't get printed, so should
		 * get stripped from the output:
		 *
		case I40E_MSIX_PBA(0):
		case I40E_MSIX_TMSG(0):
		case I40E_MSIX_TUADD(0):
		case I40E_MSIX_TVCTRL(0):
		case I40E_PFPCI_VF_FLUSH_DONE:
		case I40E_PFPCI_VF_FLUSH_DONE1(0):
		case I40E_VPQF_CTL(0):
		case I40E_QRX_TAIL1(0):
		case I40E_PRTMAC_HSEC_CTL_RX_ENABLE_GCP:
		case I40E_PRTMAC_HSEC_CTL_RX_ENABLE_GPP:
		case I40E_PRTMAC_HSEC_CTL_RX_ENABLE_PPP:
		case I40E_PRTMAC_HSEC_CTL_RX_FORWARD_CONTROL:
		case I40E_PRTMAC_HSEC_CTL_RX_PAUSE_DA_UCAST_PART1:
		case I40E_PRTMAC_HSEC_CTL_RX_PAUSE_DA_UCAST_PART2:
		case I40E_PRTMAC_HSEC_CTL_RX_PAUSE_ENABLE:
		case I40E_PRTMAC_HSEC_CTL_RX_PAUSE_SA_PART1:
		case I40E_PRTMAC_HSEC_CTL_RX_PAUSE_SA_PART2:
		case I40E_PRTMAC_HSEC_CTL_TX_PAUSE_ENABLE:
		case I40E_PRTMAC_HSEC_CTL_TX_PAUSE_QUANTA(0):
		case I40E_PRTMAC_HSEC_CTL_TX_PAUSE_REFRESH_TIMER(0):
		case I40E_PRTMAC_HSEC_CTL_TX_SA_PART1:
		case I40E_PRTMAC_HSEC_CTL_TX_SA_PART2:
		 */

		case I40E_GL_ARQBAH:
			sprintf(name, "GL_ARQBAH"); break;
		case I40E_GL_ARQBAL:
			sprintf(name, "GL_ARQBAL"); break;
		case I40E_GL_ARQH:
			sprintf(name, "GL_ARQH"); break;
		case I40E_GL_ARQT:
			sprintf(name, "GL_ARQT"); break;
		case I40E_GL_ATQBAH:
			sprintf(name, "GL_ATQBAH"); break;
		case I40E_GL_ATQBAL:
			sprintf(name, "GL_ATQBAL"); break;
		case I40E_GL_ATQH:
			sprintf(name, "GL_ATQH"); break;
		case I40E_GL_ATQLEN:
			sprintf(name, "GL_ATQLEN"); break;
		case I40E_GL_ATQT:
			sprintf(name, "GL_ATQT"); break;
		case I40E_PF_ARQBAH:
			sprintf(name, "PF_ARQBAH"); break;
		case I40E_PF_ARQBAL:
			sprintf(name, "PF_ARQBAL"); break;
		case I40E_PF_ARQH:
			sprintf(name, "PF_ARQH"); break;
		case I40E_PF_ARQLEN:
			sprintf(name, "PF_ARQLEN"); break;
		case I40E_PF_ARQT:
			sprintf(name, "PF_ARQT"); break;
		case I40E_PF_ATQBAH:
			sprintf(name, "PF_ATQBAH"); break;
		case I40E_PF_ATQBAL:
			sprintf(name, "PF_ATQBAL"); break;
		case I40E_PF_ATQH:
			sprintf(name, "PF_ATQH"); break;
		case I40E_PF_ATQLEN:
			sprintf(name, "PF_ATQLEN"); break;
		case I40E_PF_ATQT:
			sprintf(name, "PF_ATQT"); break;
		case I40E_PRT_L2TAGSEN:
			sprintf(name, "PRT_L2TAGSEN"); break;
		case I40E_PFCM_LAN_ERRDATA:
			sprintf(name, "PFCM_LAN_ERRDATA"); break;
		case I40E_PFCM_LAN_ERRINFO:
			sprintf(name, "PFCM_LAN_ERRINFO"); break;
		case I40E_PFCM_LANCTXCTL:
			sprintf(name, "PFCM_LANCTXCTL"); break;
		case I40E_PFCM_LANCTXDATA(0):
			sprintf(name, "PFCM_LANCTXDATA(0)"); break;
		case I40E_PFCM_LANCTXSTAT:
			sprintf(name, "PFCM_LANCTXSTAT"); break;
		case I40E_GLDCB_GENC:
			sprintf(name, "GLDCB_GENC"); break;
		case I40E_GLDCB_RUPTI:
			sprintf(name, "GLDCB_RUPTI"); break;
		case I40E_PRTDCB_FCCFG:
			sprintf(name, "PRTDCB_FCCFG"); break;
		case I40E_PRTDCB_FCRTV:
			sprintf(name, "PRTDCB_FCRTV"); break;
		case I40E_PRTDCB_FCTTVN(0):
			sprintf(name, "PRTDCB_FCTTVN(0)"); break;
		case I40E_PRTDCB_GENC:
			sprintf(name, "PRTDCB_GENC"); break;
		case I40E_PRTDCB_GENS:
			sprintf(name, "PRTDCB_GENS"); break;
		case I40E_PRTDCB_MFLCN:
			sprintf(name, "PRTDCB_MFLCN"); break;
		case I40E_PRTDCB_RETSC:
			sprintf(name, "PRTDCB_RETSC"); break;
		case I40E_PRTDCB_RETSTCC(0):
			sprintf(name, "PRTDCB_RETSTCC(0)"); break;
		case I40E_PRTDCB_RPPMC:
			sprintf(name, "PRTDCB_RPPMC"); break;
		case I40E_PRTDCB_RUP:
			sprintf(name, "PRTDCB_RUP"); break;
		case I40E_PRTDCB_RUP2TC:
			sprintf(name, "PRTDCB_RUP2TC"); break;
		case I40E_PRTDCB_RUPTQ(0):
			sprintf(name, "PRTDCB_RUPTQ(0)"); break;
		case I40E_PRTDCB_TC2PFC:
			sprintf(name, "PRTDCB_TC2PFC"); break;
		case I40E_PRTDCB_TCMSTC(0):
			sprintf(name, "PRTDCB_TCMSTC(0)"); break;
		case I40E_PRTDCB_TCPMC:
			sprintf(name, "PRTDCB_TCPMC"); break;
		case I40E_PRTDCB_TCWSTC(0):
			sprintf(name, "PRTDCB_TCWSTC(0)"); break;
		case I40E_PRTDCB_TDPMC:
			sprintf(name, "PRTDCB_TDPMC"); break;
		case I40E_PRTDCB_TETSC_TCB:
			sprintf(name, "PRTDCB_TETSC_TCB"); break;
		case I40E_PRTDCB_TETSC_TPB:
			sprintf(name, "PRTDCB_TETSC_TPB"); break;
		case I40E_PRTDCB_TFCS:
			sprintf(name, "PRTDCB_TFCS"); break;
		case I40E_PRTDCB_TPFCTS(0):
			sprintf(name, "PRTDCB_TPFCTS(0)"); break;
		case I40E_GLFCOE_RCTL:
			sprintf(name, "GLFCOE_RCTL"); break;
		case I40E_GL_FWSTS:
			sprintf(name, "GL_FWSTS"); break;
		case I40E_GLGEN_CLKSTAT:
			sprintf(name, "GLGEN_CLKSTAT"); break;
		case I40E_GLGEN_GPIO_CTL(0):
			sprintf(name, "GLGEN_GPIO_CTL(0)"); break;
		case I40E_GLGEN_GPIO_SET:
			sprintf(name, "GLGEN_GPIO_SET"); break;
		case I40E_GLGEN_GPIO_STAT:
			sprintf(name, "GLGEN_GPIO_STAT"); break;
		case I40E_GLGEN_GPIO_TRANSIT:
			sprintf(name, "GLGEN_GPIO_TRANSIT"); break;
		case I40E_GLGEN_I2CCMD(0):
			sprintf(name, "GLGEN_I2CCMD(0)"); break;
		case I40E_GLGEN_I2CPARAMS(0):
			sprintf(name, "GLGEN_I2CPARAMS(0)"); break;
		case I40E_GLGEN_LED_CTL:
			sprintf(name, "GLGEN_LED_CTL"); break;
		case I40E_GLGEN_MDIO_CTRL(0):
			sprintf(name, "GLGEN_MDIO_CTRL(0)"); break;
		case I40E_GLGEN_MDIO_I2C_SEL(0):
			sprintf(name, "GLGEN_MDIO_I2C_SEL(0)"); break;
		case I40E_GLGEN_MSCA(0):
			sprintf(name, "GLGEN_MSCA(0)"); break;
		case I40E_GLGEN_MSRWD(0):
			sprintf(name, "GLGEN_MSRWD(0)"); break;
		case I40E_GLGEN_PCIFCNCNT:
			sprintf(name, "GLGEN_PCIFCNCNT"); break;
		case I40E_GLGEN_RSTAT:
			sprintf(name, "GLGEN_RSTAT"); break;
		case I40E_GLGEN_RSTCTL:
			sprintf(name, "GLGEN_RSTCTL"); break;
		case I40E_GLGEN_RTRIG:
			sprintf(name, "GLGEN_RTRIG"); break;
		case I40E_GLGEN_STAT:
			sprintf(name, "GLGEN_STAT"); break;
		case I40E_GLGEN_VFLRSTAT(0):
			sprintf(name, "GLGEN_VFLRSTAT(0)"); break;
		case I40E_GLVFGEN_TIMER:
			sprintf(name, "GLVFGEN_TIMER"); break;
		case I40E_PFGEN_CTRL:
			sprintf(name, "PFGEN_CTRL"); break;
		case I40E_PFGEN_DRUN:
			sprintf(name, "PFGEN_DRUN"); break;
		case I40E_PFGEN_PORTNUM:
			sprintf(name, "PFGEN_PORTNUM"); break;
		case I40E_PFGEN_STATE:
			sprintf(name, "PFGEN_STATE"); break;
		case I40E_PRTGEN_CNF:
			sprintf(name, "PRTGEN_CNF"); break;
		case I40E_PRTGEN_CNF2:
			sprintf(name, "PRTGEN_CNF2"); break;
		case I40E_PRTGEN_STATUS:
			sprintf(name, "PRTGEN_STATUS"); break;
		case I40E_VPGEN_VFRSTAT(0):
			sprintf(name, "VPGEN_VFRSTAT(0)"); break;
		case I40E_VPGEN_VFRTRIG(0):
			sprintf(name, "VPGEN_VFRTRIG(0)"); break;
		case I40E_VSIGEN_RSTAT(0):
			sprintf(name, "VSIGEN_RSTAT(0)"); break;
		case I40E_VSIGEN_RTRIG(0):
			sprintf(name, "VSIGEN_RTRIG(0)"); break;
		case I40E_GLHMC_FCOEDDPBASE(0):
			sprintf(name, "GLHMC_FCOEDDPBASE(0)"); break;
		case I40E_GLHMC_FCOEDDPCNT(0):
			sprintf(name, "GLHMC_FCOEDDPCNT(0)"); break;
		case I40E_GLHMC_FCOEDDPOBJSZ:
			sprintf(name, "GLHMC_FCOEDDPOBJSZ"); break;
		case I40E_GLHMC_FCOEFBASE(0):
			sprintf(name, "GLHMC_FCOEFBASE(0)"); break;
		case I40E_GLHMC_FCOEFCNT(0):
			sprintf(name, "GLHMC_FCOEFCNT(0)"); break;
		case I40E_GLHMC_FCOEFMAX:
			sprintf(name, "GLHMC_FCOEFMAX"); break;
		case I40E_GLHMC_FCOEFOBJSZ:
			sprintf(name, "GLHMC_FCOEFOBJSZ"); break;
		case I40E_GLHMC_FCOEMAX:
			sprintf(name, "GLHMC_FCOEMAX"); break;
		case I40E_GLHMC_FSIAVBASE(0):
			sprintf(name, "GLHMC_FSIAVBASE(0)"); break;
		case I40E_GLHMC_FSIAVCNT(0):
			sprintf(name, "GLHMC_FSIAVCNT(0)"); break;
		case I40E_GLHMC_FSIAVMAX:
			sprintf(name, "GLHMC_FSIAVMAX"); break;
		case I40E_GLHMC_FSIAVOBJSZ:
			sprintf(name, "GLHMC_FSIAVOBJSZ"); break;
		case I40E_GLHMC_FSIMCBASE(0):
			sprintf(name, "GLHMC_FSIMCBASE(0)"); break;
		case I40E_GLHMC_FSIMCCNT(0):
			sprintf(name, "GLHMC_FSIMCCNT(0)"); break;
		case I40E_GLHMC_FSIMCMAX:
			sprintf(name, "GLHMC_FSIMCMAX"); break;
		case I40E_GLHMC_FSIMCOBJSZ:
			sprintf(name, "GLHMC_FSIMCOBJSZ"); break;
		case I40E_GLHMC_LANQMAX:
			sprintf(name, "GLHMC_LANQMAX"); break;
		case I40E_GLHMC_LANRXBASE(0):
			sprintf(name, "GLHMC_LANRXBASE(0)"); break;
		case I40E_GLHMC_LANRXCNT(0):
			sprintf(name, "GLHMC_LANRXCNT(0)"); break;
		case I40E_GLHMC_LANRXOBJSZ:
			sprintf(name, "GLHMC_LANRXOBJSZ"); break;
		case I40E_GLHMC_LANTXBASE(0):
			sprintf(name, "GLHMC_LANTXBASE(0)"); break;
		case I40E_GLHMC_LANTXCNT(0):
			sprintf(name, "GLHMC_LANTXCNT(0)"); break;
		case I40E_GLHMC_LANTXOBJSZ:
			sprintf(name, "GLHMC_LANTXOBJSZ"); break;
		case I40E_GLHMC_PFASSIGN(0):
			sprintf(name, "GLHMC_PFASSIGN(0)"); break;
		case I40E_GLHMC_SDPART(0):
			sprintf(name, "GLHMC_SDPART(0)"); break;
		case I40E_PFHMC_ERRORDATA:
			sprintf(name, "PFHMC_ERRORDATA"); break;
		case I40E_PFHMC_ERRORINFO:
			sprintf(name, "PFHMC_ERRORINFO"); break;
		case I40E_PFHMC_PDINV:
			sprintf(name, "PFHMC_PDINV"); break;
		case I40E_PFHMC_SDCMD:
			sprintf(name, "PFHMC_SDCMD"); break;
		case I40E_PFHMC_SDDATAHIGH:
			sprintf(name, "PFHMC_SDDATAHIGH"); break;
		case I40E_PFHMC_SDDATALOW:
			sprintf(name, "PFHMC_SDDATALOW"); break;
		case I40E_GL_GP_FUSE(0):
			sprintf(name, "GL_GP_FUSE(0)"); break;
		case I40E_GL_UFUSE:
			sprintf(name, "GL_UFUSE"); break;
		case I40E_EMPINT_GPIO_ENA:
			sprintf(name, "EMPINT_GPIO_ENA"); break;
		case I40E_PFGEN_PORTMDIO_NUM:
			sprintf(name, "PFGEN_PORTMDIO_NUM"); break;
		case I40E_PFINT_AEQCTL:
			sprintf(name, "PFINT_AEQCTL"); break;
		case I40E_PFINT_CEQCTL(0):
			sprintf(name, "PFINT_CEQCTL(0)"); break;
		case I40E_PFINT_DYN_CTL0:
			sprintf(name, "PFINT_DYN_CTL0"); break;
		case I40E_PFINT_DYN_CTLN(0):
			sprintf(name, "PFINT_DYN_CTLN(0)"); break;
		case I40E_PFINT_GPIO_ENA:
			sprintf(name, "PFINT_GPIO_ENA"); break;
		case I40E_PFINT_ICR0:
			sprintf(name, "PFINT_ICR0"); break;
		case I40E_PFINT_ICR0_ENA:
			sprintf(name, "PFINT_ICR0_ENA"); break;
		case I40E_PFINT_ITR0(0):
			sprintf(name, "PFINT_ITR0(0)"); break;
		case I40E_PFINT_ITRN(0,0):
			sprintf(name, "PFINT_ITRN(0,0)"); break;
		case I40E_PFINT_LNKLST0:
			sprintf(name, "PFINT_LNKLST0"); break;
		case I40E_PFINT_LNKLSTN(0):
			sprintf(name, "PFINT_LNKLSTN(0)"); break;
		case I40E_PFINT_RATE0:
			sprintf(name, "PFINT_RATE0"); break;
		case I40E_PFINT_RATEN(0):
			sprintf(name, "PFINT_RATEN(0)"); break;
		case I40E_PFINT_STAT_CTL0:
			sprintf(name, "PFINT_STAT_CTL0"); break;
		case I40E_QINT_RQCTL(0):
			sprintf(name, "QINT_RQCTL(0)"); break;
		case I40E_QINT_TQCTL(0):
			sprintf(name, "QINT_TQCTL(0)"); break;
		case I40E_VPINT_AEQCTL(0):
			sprintf(name, "VPINT_AEQCTL(0)"); break;
		case I40E_VPINT_CEQCTL(0):
			sprintf(name, "VPINT_CEQCTL(0)"); break;
		case I40E_VPINT_LNKLST0(0):
			sprintf(name, "VPINT_LNKLST0(0)"); break;
		case I40E_VPINT_LNKLSTN(0):
			sprintf(name, "VPINT_LNKLSTN(0)"); break;
		case I40E_VPINT_RATE0(0):
			sprintf(name, "VPINT_RATE0(0)"); break;
		case I40E_VPINT_RATEN(0):
			sprintf(name, "VPINT_RATEN(0)"); break;
		case I40E_GL_RDPU_CNTRL:
			sprintf(name, "GL_RDPU_CNTRL"); break;
		case I40E_GLLAN_RCTL_0:
			sprintf(name, "GLLAN_RCTL_0"); break;
		case I40E_GLLAN_TSOMSK_F:
			sprintf(name, "GLLAN_TSOMSK_F"); break;
		case I40E_GLLAN_TSOMSK_L:
			sprintf(name, "GLLAN_TSOMSK_L"); break;
		case I40E_GLLAN_TSOMSK_M:
			sprintf(name, "GLLAN_TSOMSK_M"); break;
		case I40E_GLLAN_TXPRE_QDIS(0):
			sprintf(name, "GLLAN_TXPRE_QDIS(0)"); break;
		case I40E_PFLAN_QALLOC:
			sprintf(name, "PFLAN_QALLOC"); break;
		case I40E_QRX_ENA(0):
			sprintf(name, "QRX_ENA(0)"); break;
		case I40E_QRX_TAIL(0):
			sprintf(name, "QRX_TAIL(0)"); break;
		case I40E_QTX_CTL(0):
			sprintf(name, "QTX_CTL(0)"); break;
		case I40E_QTX_ENA(0):
			sprintf(name, "QTX_ENA(0)"); break;
		case I40E_QTX_HEAD(0):
			sprintf(name, "QTX_HEAD(0)"); break;
		case I40E_QTX_TAIL(0):
			sprintf(name, "QTX_TAIL(0)"); break;
		case I40E_VPLAN_MAPENA(0):
			sprintf(name, "VPLAN_MAPENA(0)"); break;
		case I40E_VPLAN_QTABLE(0,0):
			sprintf(name, "VPLAN_QTABLE(0,0)"); break;
		case I40E_VSILAN_QBASE(0):
			sprintf(name, "VSILAN_QBASE(0)"); break;
		case I40E_VSILAN_QTABLE(0,0):
			sprintf(name, "VSILAN_QTABLE(0,0)"); break;
		case I40E_PRTGL_SAH:
			sprintf(name, "PRTGL_SAH"); break;
		case I40E_PRTGL_SAL:
			sprintf(name, "PRTGL_SAL"); break;
		case I40E_PRTMAC_PCS_XAUI_SWAP_A:
			sprintf(name, "PRTMAC_PCS_XAUI_SWAP_A"); break;
		case I40E_PRTMAC_PCS_XAUI_SWAP_B:
			sprintf(name, "PRTMAC_PCS_XAUI_SWAP_B"); break;
		case I40E_GL_FWRESETCNT:
			sprintf(name, "GL_FWRESETCNT"); break;
		case I40E_GL_MNG_FWSM:
			sprintf(name, "GL_MNG_FWSM"); break;
		case I40E_GL_MNG_HWARB_CTRL:
			sprintf(name, "GL_MNG_HWARB_CTRL"); break;
		case I40E_PRT_MNG_FTFT_DATA(0):
			sprintf(name, "PRT_MNG_FTFT_DATA(0)"); break;
		case I40E_PRT_MNG_FTFT_LENGTH:
			sprintf(name, "PRT_MNG_FTFT_LENGTH"); break;
		case I40E_PRT_MNG_FTFT_MASK(0):
			sprintf(name, "PRT_MNG_FTFT_MASK(0)"); break;
		case I40E_PRT_MNG_MANC:
			sprintf(name, "PRT_MNG_MANC"); break;
		case I40E_PRT_MNG_MAVTV(0):
			sprintf(name, "PRT_MNG_MAVTV(0)"); break;
		case I40E_PRT_MNG_MDEF(0):
			sprintf(name, "PRT_MNG_MDEF(0)"); break;
		case I40E_PRT_MNG_MDEF_EXT(0):
			sprintf(name, "PRT_MNG_MDEF_EXT(0)"); break;
		case I40E_PRT_MNG_MDEFVSI(0):
			sprintf(name, "PRT_MNG_MDEFVSI(0)"); break;
		case I40E_PRT_MNG_METF(0):
			sprintf(name, "PRT_MNG_METF(0)"); break;
		case I40E_PRT_MNG_MFUTP(0):
			sprintf(name, "PRT_MNG_MFUTP(0)"); break;
		case I40E_PRT_MNG_MIPAF4(0):
			sprintf(name, "PRT_MNG_MIPAF4(0)"); break;
		case I40E_PRT_MNG_MIPAF6(0):
			sprintf(name, "PRT_MNG_MIPAF6(0)"); break;
		case I40E_PRT_MNG_MMAH(0):
			sprintf(name, "PRT_MNG_MMAH(0)"); break;
		case I40E_PRT_MNG_MMAL(0):
			sprintf(name, "PRT_MNG_MMAL(0)"); break;
		case I40E_PRT_MNG_MNGONLY:
			sprintf(name, "PRT_MNG_MNGONLY"); break;
		case I40E_PRT_MNG_MSFM:
			sprintf(name, "PRT_MNG_MSFM"); break;
		case I40E_GLNVM_FLA:
			sprintf(name, "GLNVM_FLA"); break;
		case I40E_GLNVM_FLASHID:
			sprintf(name, "GLNVM_FLASHID"); break;
		case I40E_GLNVM_GENS:
			sprintf(name, "GLNVM_GENS"); break;
		case I40E_GLNVM_PROTCSR(0):
			sprintf(name, "GLNVM_PROTCSR(0)"); break;
		case I40E_GLNVM_SRCTL:
			sprintf(name, "GLNVM_SRCTL"); break;
		case I40E_GLNVM_SRDATA:
			sprintf(name, "GLNVM_SRDATA"); break;
		case I40E_GLNVM_ULD:
			sprintf(name, "GLNVM_ULD"); break;
		case I40E_GLPCI_BYTCTH:
			sprintf(name, "GLPCI_BYTCTH"); break;
		case I40E_GLPCI_BYTCTL:
			sprintf(name, "GLPCI_BYTCTL"); break;
		case I40E_GLPCI_CAPCTRL:
			sprintf(name, "GLPCI_CAPCTRL"); break;
		case I40E_GLPCI_CAPSUP:
			sprintf(name, "GLPCI_CAPSUP"); break;
		case I40E_GLPCI_CNF:
			sprintf(name, "GLPCI_CNF"); break;
		case I40E_GLPCI_CNF2:
			sprintf(name, "GLPCI_CNF2"); break;
		case I40E_GLPCI_DREVID:
			sprintf(name, "GLPCI_DREVID"); break;
		case I40E_GLPCI_GSCL_1:
			sprintf(name, "GLPCI_GSCL_1"); break;
		case I40E_GLPCI_GSCL_2:
			sprintf(name, "GLPCI_GSCL_2"); break;
		case I40E_GLPCI_GSCL_5_8(0):
			sprintf(name, "GLPCI_GSCL_5_8(0)"); break;
		case I40E_GLPCI_GSCN_0_3(0):
			sprintf(name, "GLPCI_GSCN_0_3(0)"); break;
		case I40E_GLPCI_LBARCTRL:
			sprintf(name, "GLPCI_LBARCTRL"); break;
		case I40E_GLPCI_LINKCAP:
			sprintf(name, "GLPCI_LINKCAP"); break;
		case I40E_GLPCI_PCIERR:
			sprintf(name, "GLPCI_PCIERR"); break;
		case I40E_GLPCI_PKTCT:
			sprintf(name, "GLPCI_PKTCT"); break;
		case I40E_GLPCI_PM_MUX_NPQ:
			sprintf(name, "GLPCI_PM_MUX_NPQ"); break;
		case I40E_GLPCI_PM_MUX_PFB:
			sprintf(name, "GLPCI_PM_MUX_PFB"); break;
		case I40E_GLPCI_PMSUP:
			sprintf(name, "GLPCI_PMSUP"); break;
		case I40E_GLPCI_PQ_MAX_USED_SPC:
			sprintf(name, "GLPCI_PQ_MAX_USED_SPC"); break;
		case I40E_GLPCI_PWRDATA:
			sprintf(name, "GLPCI_PWRDATA"); break;
		case I40E_GLPCI_REVID:
			sprintf(name, "GLPCI_REVID"); break;
		case I40E_GLPCI_SERH:
			sprintf(name, "GLPCI_SERH"); break;
		case I40E_GLPCI_SERL:
			sprintf(name, "GLPCI_SERL"); break;
		case I40E_GLPCI_SPARE_BITS_0:
			sprintf(name, "GLPCI_SPARE_BITS_0"); break;
		case I40E_GLPCI_SPARE_BITS_1:
			sprintf(name, "GLPCI_SPARE_BITS_1"); break;
		case I40E_GLPCI_SUBVENID:
			sprintf(name, "GLPCI_SUBVENID"); break;
		case I40E_GLPCI_UPADD:
			sprintf(name, "GLPCI_UPADD"); break;
		case I40E_GLPCI_VENDORID:
			sprintf(name, "GLPCI_VENDORID"); break;
		case I40E_GLPCI_VFSUP:
			sprintf(name, "GLPCI_VFSUP"); break;
		case I40E_GLTPH_CTRL:
			sprintf(name, "GLTPH_CTRL"); break;
		case I40E_PF_FUNC_RID:
			sprintf(name, "PF_FUNC_RID"); break;
		case I40E_PF_PCI_CIAA:
			sprintf(name, "PF_PCI_CIAA"); break;
		case I40E_PF_PCI_CIAD:
			sprintf(name, "PF_PCI_CIAD"); break;
		case I40E_PFPCI_CLASS:
			sprintf(name, "PFPCI_CLASS"); break;
		case I40E_PFPCI_CNF:
			sprintf(name, "PFPCI_CNF"); break;
		case I40E_PFPCI_DEVID:
			sprintf(name, "PFPCI_DEVID"); break;
		case I40E_PFPCI_FACTPS:
			sprintf(name, "PFPCI_FACTPS"); break;
		case I40E_PFPCI_FUNC:
			sprintf(name, "PFPCI_FUNC"); break;
		case I40E_PFPCI_FUNC2:
			sprintf(name, "PFPCI_FUNC2"); break;
		case I40E_PFPCI_ICAUSE:
			sprintf(name, "PFPCI_ICAUSE"); break;
		case I40E_PFPCI_IENA:
			sprintf(name, "PFPCI_IENA"); break;
		case I40E_PFPCI_PF_FLUSH_DONE:
			sprintf(name, "PFPCI_PF_FLUSH_DONE"); break;
		case I40E_PFPCI_PM:
			sprintf(name, "PFPCI_PM"); break;
		case I40E_PFPCI_STATUS1:
			sprintf(name, "PFPCI_STATUS1"); break;
		case I40E_PFPCI_SUBSYSID:
			sprintf(name, "PFPCI_SUBSYSID"); break;
		case I40E_PFPCI_VM_FLUSH_DONE:
			sprintf(name, "PFPCI_VM_FLUSH_DONE"); break;
		case I40E_PFPCI_VMINDEX:
			sprintf(name, "PFPCI_VMINDEX"); break;
		case I40E_PFPCI_VMPEND:
			sprintf(name, "PFPCI_VMPEND"); break;
		case I40E_PRTPM_EEE_STAT:
			sprintf(name, "PRTPM_EEE_STAT"); break;
		case I40E_PRTPM_EEEC:
			sprintf(name, "PRTPM_EEEC"); break;
		case I40E_PRTPM_EEEFWD:
			sprintf(name, "PRTPM_EEEFWD"); break;
		case I40E_PRTPM_EEER:
			sprintf(name, "PRTPM_EEER"); break;
		case I40E_PRTPM_EEETXC:
			sprintf(name, "PRTPM_EEETXC"); break;
		case I40E_PRTPM_GC:
			sprintf(name, "PRTPM_GC"); break;
		case I40E_PRTPM_RLPIC:
			sprintf(name, "PRTPM_RLPIC"); break;
		case I40E_PRTPM_TLPIC:
			sprintf(name, "PRTPM_TLPIC"); break;
		case I40E_GLRPB_DPSS:
			sprintf(name, "GLRPB_DPSS"); break;
		case I40E_GLRPB_GHW:
			sprintf(name, "GLRPB_GHW"); break;
		case I40E_GLRPB_GLW:
			sprintf(name, "GLRPB_GLW"); break;
		case I40E_GLRPB_PHW:
			sprintf(name, "GLRPB_PHW"); break;
		case I40E_GLRPB_PLW:
			sprintf(name, "GLRPB_PLW"); break;
		case I40E_PRTRPB_DHW(0):
			sprintf(name, "PRTRPB_DHW(0)"); break;
		case I40E_PRTRPB_DLW(0):
			sprintf(name, "PRTRPB_DLW(0)"); break;
		case I40E_PRTRPB_DPS(0):
			sprintf(name, "PRTRPB_DPS(0)"); break;
		case I40E_PRTRPB_SHT(0):
			sprintf(name, "PRTRPB_SHT(0)"); break;
		case I40E_PRTRPB_SHW:
			sprintf(name, "PRTRPB_SHW"); break;
		case I40E_PRTRPB_SLT(0):
			sprintf(name, "PRTRPB_SLT(0)"); break;
		case I40E_PRTRPB_SLW:
			sprintf(name, "PRTRPB_SLW"); break;
		case I40E_PRTRPB_SPS:
			sprintf(name, "PRTRPB_SPS"); break;
		case I40E_GLQF_CTL:
			sprintf(name, "GLQF_CTL"); break;
		case I40E_GLQF_FDCNT_0:
			sprintf(name, "GLQF_FDCNT_0"); break;
		case I40E_GLQF_HKEY(0):
			sprintf(name, "GLQF_HKEY(0)"); break;
		case I40E_GLQF_HSYM(0):
			sprintf(name, "GLQF_HSYM(0)"); break;
		case I40E_GLQF_PCNT(0):
			sprintf(name, "GLQF_PCNT(0)"); break;
		case I40E_GLQF_SWAP(0,0):
			sprintf(name, "GLQF_SWAP(0,0)"); break;
		case I40E_PFQF_CTL_0:
			sprintf(name, "PFQF_CTL_0"); break;
		case I40E_PFQF_CTL_1:
			sprintf(name, "PFQF_CTL_1"); break;
		case I40E_PFQF_FDALLOC:
			sprintf(name, "PFQF_FDALLOC"); break;
		case I40E_PFQF_FDSTAT:
			sprintf(name, "PFQF_FDSTAT"); break;
		case I40E_PFQF_HENA(0):
			sprintf(name, "PFQF_HENA(0)"); break;
		case I40E_PFQF_HKEY(0):
			sprintf(name, "PFQF_HKEY(0)"); break;
		case I40E_PFQF_HLUT(0):
			sprintf(name, "PFQF_HLUT(0)"); break;
		case I40E_PRTQF_CTL_0:
			sprintf(name, "PRTQF_CTL_0"); break;
		case I40E_PRTQF_FD_FLXINSET(0):
			sprintf(name, "PRTQF_FD_FLXINSET(0)"); break;
		case I40E_PRTQF_FD_MSK(0,0):
			sprintf(name, "PRTQF_FD_MSK(0,0)"); break;
		case I40E_PRTQF_FLX_PIT(0):
			sprintf(name, "PRTQF_FLX_PIT(0)"); break;
		case I40E_VSIQF_CTL(0):
			sprintf(name, "VSIQF_CTL(0)"); break;
		case I40E_VSIQF_TCREGION(0,0):
			sprintf(name, "VSIQF_TCREGION(0,0)"); break;
		case I40E_GL_FCOECRC(0):
			sprintf(name, "GL_FCOECRC(0)"); break;
		case I40E_GL_FCOEDDPC(0):
			sprintf(name, "GL_FCOEDDPC(0)"); break;
		case I40E_GL_FCOEDIFEC(0):
			sprintf(name, "GL_FCOEDIFEC(0)"); break;
		case I40E_GL_FCOEDIFTCL(0):
			sprintf(name, "GL_FCOEDIFTCL(0)"); break;
		case I40E_GL_FCOEDIXEC(0):
			sprintf(name, "GL_FCOEDIXEC(0)"); break;
		case I40E_GL_FCOEDIXVC(0):
			sprintf(name, "GL_FCOEDIXVC(0)"); break;
		case I40E_GL_FCOEDWRCH(0):
			sprintf(name, "GL_FCOEDWRCH(0)"); break;
		case I40E_GL_FCOEDWRCL(0):
			sprintf(name, "GL_FCOEDWRCL(0)"); break;
		case I40E_GL_FCOEDWTCH(0):
			sprintf(name, "GL_FCOEDWTCH(0)"); break;
		case I40E_GL_FCOEDWTCL(0):
			sprintf(name, "GL_FCOEDWTCL(0)"); break;
		case I40E_GL_FCOELAST(0):
			sprintf(name, "GL_FCOELAST(0)"); break;
		case I40E_GL_FCOEPRC(0):
			sprintf(name, "GL_FCOEPRC(0)"); break;
		case I40E_GL_FCOEPTC(0):
			sprintf(name, "GL_FCOEPTC(0)"); break;
		case I40E_GL_FCOERPDC(0):
			sprintf(name, "GL_FCOERPDC(0)"); break;
		case I40E_GL_RXERR1_L(0):
			sprintf(name, "GL_RXERR1_L(0)"); break;
		case I40E_GL_RXERR2_L(0):
			sprintf(name, "GL_RXERR2_L(0)"); break;
		case I40E_GLPRT_BPRCH(0):
			sprintf(name, "GLPRT_BPRCH(0)"); break;
		case I40E_GLPRT_BPRCL(0):
			sprintf(name, "GLPRT_BPRCL(0)"); break;
		case I40E_GLPRT_BPTCH(0):
			sprintf(name, "GLPRT_BPTCH(0)"); break;
		case I40E_GLPRT_BPTCL(0):
			sprintf(name, "GLPRT_BPTCL(0)"); break;
		case I40E_GLPRT_CRCERRS(0):
			sprintf(name, "GLPRT_CRCERRS(0)"); break;
		case I40E_GLPRT_GORCH(0):
			sprintf(name, "GLPRT_GORCH(0)"); break;
		case I40E_GLPRT_GORCL(0):
			sprintf(name, "GLPRT_GORCL(0)"); break;
		case I40E_GLPRT_GOTCH(0):
			sprintf(name, "GLPRT_GOTCH(0)"); break;
		case I40E_GLPRT_GOTCL(0):
			sprintf(name, "GLPRT_GOTCL(0)"); break;
		case I40E_GLPRT_ILLERRC(0):
			sprintf(name, "GLPRT_ILLERRC(0)"); break;
		case I40E_GLPRT_LDPC(0):
			sprintf(name, "GLPRT_LDPC(0)"); break;
		case I40E_GLPRT_LXOFFRXC(0):
			sprintf(name, "GLPRT_LXOFFRXC(0)"); break;
		case I40E_GLPRT_LXOFFTXC(0):
			sprintf(name, "GLPRT_LXOFFTXC(0)"); break;
		case I40E_GLPRT_LXONRXC(0):
			sprintf(name, "GLPRT_LXONRXC(0)"); break;
		case I40E_GLPRT_LXONTXC(0):
			sprintf(name, "GLPRT_LXONTXC(0)"); break;
		case I40E_GLPRT_MLFC(0):
			sprintf(name, "GLPRT_MLFC(0)"); break;
		case I40E_GLPRT_MPRCH(0):
			sprintf(name, "GLPRT_MPRCH(0)"); break;
		case I40E_GLPRT_MPRCL(0):
			sprintf(name, "GLPRT_MPRCL(0)"); break;
		case I40E_GLPRT_MPTCH(0):
			sprintf(name, "GLPRT_MPTCH(0)"); break;
		case I40E_GLPRT_MPTCL(0):
			sprintf(name, "GLPRT_MPTCL(0)"); break;
		case I40E_GLPRT_MRFC(0):
			sprintf(name, "GLPRT_MRFC(0)"); break;
		case I40E_GLPRT_PRC1023H(0):
			sprintf(name, "GLPRT_PRC1023H(0)"); break;
		case I40E_GLPRT_PRC1023L(0):
			sprintf(name, "GLPRT_PRC1023L(0)"); break;
		case I40E_GLPRT_PRC127H(0):
			sprintf(name, "GLPRT_PRC127H(0)"); break;
		case I40E_GLPRT_PRC127L(0):
			sprintf(name, "GLPRT_PRC127L(0)"); break;
		case I40E_GLPRT_PRC1522H(0):
			sprintf(name, "GLPRT_PRC1522H(0)"); break;
		case I40E_GLPRT_PRC1522L(0):
			sprintf(name, "GLPRT_PRC1522L(0)"); break;
		case I40E_GLPRT_PRC255H(0):
			sprintf(name, "GLPRT_PRC255H(0)"); break;
		case I40E_GLPRT_PRC255L(0):
			sprintf(name, "GLPRT_PRC255L(0)"); break;
		case I40E_GLPRT_PRC511H(0):
			sprintf(name, "GLPRT_PRC511H(0)"); break;
		case I40E_GLPRT_PRC511L(0):
			sprintf(name, "GLPRT_PRC511L(0)"); break;
		case I40E_GLPRT_PRC64H(0):
			sprintf(name, "GLPRT_PRC64H(0)"); break;
		case I40E_GLPRT_PRC64L(0):
			sprintf(name, "GLPRT_PRC64L(0)"); break;
		case I40E_GLPRT_PRC9522H(0):
			sprintf(name, "GLPRT_PRC9522H(0)"); break;
		case I40E_GLPRT_PRC9522L(0):
			sprintf(name, "GLPRT_PRC9522L(0)"); break;
		case I40E_GLPRT_PTC1023H(0):
			sprintf(name, "GLPRT_PTC1023H(0)"); break;
		case I40E_GLPRT_PTC1023L(0):
			sprintf(name, "GLPRT_PTC1023L(0)"); break;
		case I40E_GLPRT_PTC127H(0):
			sprintf(name, "GLPRT_PTC127H(0)"); break;
		case I40E_GLPRT_PTC127L(0):
			sprintf(name, "GLPRT_PTC127L(0)"); break;
		case I40E_GLPRT_PTC1522H(0):
			sprintf(name, "GLPRT_PTC1522H(0)"); break;
		case I40E_GLPRT_PTC1522L(0):
			sprintf(name, "GLPRT_PTC1522L(0)"); break;
		case I40E_GLPRT_PTC255H(0):
			sprintf(name, "GLPRT_PTC255H(0)"); break;
		case I40E_GLPRT_PTC255L(0):
			sprintf(name, "GLPRT_PTC255L(0)"); break;
		case I40E_GLPRT_PTC511H(0):
			sprintf(name, "GLPRT_PTC511H(0)"); break;
		case I40E_GLPRT_PTC511L(0):
			sprintf(name, "GLPRT_PTC511L(0)"); break;
		case I40E_GLPRT_PTC64H(0):
			sprintf(name, "GLPRT_PTC64H(0)"); break;
		case I40E_GLPRT_PTC64L(0):
			sprintf(name, "GLPRT_PTC64L(0)"); break;
		case I40E_GLPRT_PTC9522H(0):
			sprintf(name, "GLPRT_PTC9522H(0)"); break;
		case I40E_GLPRT_PTC9522L(0):
			sprintf(name, "GLPRT_PTC9522L(0)"); break;
		case I40E_GLPRT_PXOFFRXC(0,0):
			sprintf(name, "GLPRT_PXOFFRXC(0,0)"); break;
		case I40E_GLPRT_PXOFFTXC(0,0):
			sprintf(name, "GLPRT_PXOFFTXC(0,0)"); break;
		case I40E_GLPRT_PXONRXC(0,0):
			sprintf(name, "GLPRT_PXONRXC(0,0)"); break;
		case I40E_GLPRT_PXONTXC(0,0):
			sprintf(name, "GLPRT_PXONTXC(0,0)"); break;
		case I40E_GLPRT_RDPC(0):
			sprintf(name, "GLPRT_RDPC(0)"); break;
		case I40E_GLPRT_RFC(0):
			sprintf(name, "GLPRT_RFC(0)"); break;
		case I40E_GLPRT_RJC(0):
			sprintf(name, "GLPRT_RJC(0)"); break;
		case I40E_GLPRT_RLEC(0):
			sprintf(name, "GLPRT_RLEC(0)"); break;
		case I40E_GLPRT_ROC(0):
			sprintf(name, "GLPRT_ROC(0)"); break;
		case I40E_GLPRT_RUC(0):
			sprintf(name, "GLPRT_RUC(0)"); break;
		case I40E_GLPRT_RUPP(0):
			sprintf(name, "GLPRT_RUPP(0)"); break;
		case I40E_GLPRT_RXON2OFFCNT(0,0):
			sprintf(name, "GLPRT_RXON2OFFCNT(0,0)"); break;
		case I40E_GLPRT_TDOLD(0):
			sprintf(name, "GLPRT_TDOLD(0)"); break;
		case I40E_GLPRT_UPRCH(0):
			sprintf(name, "GLPRT_UPRCH(0)"); break;
		case I40E_GLPRT_UPRCL(0):
			sprintf(name, "GLPRT_UPRCL(0)"); break;
		case I40E_GLPRT_UPTCH(0):
			sprintf(name, "GLPRT_UPTCH(0)"); break;
		case I40E_GLPRT_UPTCL(0):
			sprintf(name, "GLPRT_UPTCL(0)"); break;
		case I40E_GLSW_BPRCH(0):
			sprintf(name, "GLSW_BPRCH(0)"); break;
		case I40E_GLSW_BPRCL(0):
			sprintf(name, "GLSW_BPRCL(0)"); break;
		case I40E_GLSW_BPTCH(0):
			sprintf(name, "GLSW_BPTCH(0)"); break;
		case I40E_GLSW_BPTCL(0):
			sprintf(name, "GLSW_BPTCL(0)"); break;
		case I40E_GLSW_GORCH(0):
			sprintf(name, "GLSW_GORCH(0)"); break;
		case I40E_GLSW_GORCL(0):
			sprintf(name, "GLSW_GORCL(0)"); break;
		case I40E_GLSW_GOTCH(0):
			sprintf(name, "GLSW_GOTCH(0)"); break;
		case I40E_GLSW_GOTCL(0):
			sprintf(name, "GLSW_GOTCL(0)"); break;
		case I40E_GLSW_MPRCH(0):
			sprintf(name, "GLSW_MPRCH(0)"); break;
		case I40E_GLSW_MPRCL(0):
			sprintf(name, "GLSW_MPRCL(0)"); break;
		case I40E_GLSW_MPTCH(0):
			sprintf(name, "GLSW_MPTCH(0)"); break;
		case I40E_GLSW_MPTCL(0):
			sprintf(name, "GLSW_MPTCL(0)"); break;
		case I40E_GLSW_RUPP(0):
			sprintf(name, "GLSW_RUPP(0)"); break;
		case I40E_GLSW_TDPC(0):
			sprintf(name, "GLSW_TDPC(0)"); break;
		case I40E_GLSW_UPRCH(0):
			sprintf(name, "GLSW_UPRCH(0)"); break;
		case I40E_GLSW_UPRCL(0):
			sprintf(name, "GLSW_UPRCL(0)"); break;
		case I40E_GLSW_UPTCH(0):
			sprintf(name, "GLSW_UPTCH(0)"); break;
		case I40E_GLSW_UPTCL(0):
			sprintf(name, "GLSW_UPTCL(0)"); break;
		case I40E_GLV_BPRCH(0):
			sprintf(name, "GLV_BPRCH(0)"); break;
		case I40E_GLV_BPRCL(0):
			sprintf(name, "GLV_BPRCL(0)"); break;
		case I40E_GLV_BPTCH(0):
			sprintf(name, "GLV_BPTCH(0)"); break;
		case I40E_GLV_BPTCL(0):
			sprintf(name, "GLV_BPTCL(0)"); break;
		case I40E_GLV_GORCH(0):
			sprintf(name, "GLV_GORCH(0)"); break;
		case I40E_GLV_GORCL(0):
			sprintf(name, "GLV_GORCL(0)"); break;
		case I40E_GLV_GOTCH(0):
			sprintf(name, "GLV_GOTCH(0)"); break;
		case I40E_GLV_GOTCL(0):
			sprintf(name, "GLV_GOTCL(0)"); break;
		case I40E_GLV_MPRCH(0):
			sprintf(name, "GLV_MPRCH(0)"); break;
		case I40E_GLV_MPRCL(0):
			sprintf(name, "GLV_MPRCL(0)"); break;
		case I40E_GLV_MPTCH(0):
			sprintf(name, "GLV_MPTCH(0)"); break;
		case I40E_GLV_MPTCL(0):
			sprintf(name, "GLV_MPTCL(0)"); break;
		case I40E_GLV_RDPC(0):
			sprintf(name, "GLV_RDPC(0)"); break;
		case I40E_GLV_RUPP(0):
			sprintf(name, "GLV_RUPP(0)"); break;
		case I40E_GLV_TEPC(0):
			sprintf(name, "GLV_TEPC(0)"); break;
		case I40E_GLV_UPRCH(0):
			sprintf(name, "GLV_UPRCH(0)"); break;
		case I40E_GLV_UPRCL(0):
			sprintf(name, "GLV_UPRCL(0)"); break;
		case I40E_GLV_UPTCH(0):
			sprintf(name, "GLV_UPTCH(0)"); break;
		case I40E_GLV_UPTCL(0):
			sprintf(name, "GLV_UPTCL(0)"); break;
		case I40E_GLVEBTC_RBCH(0,0):
			sprintf(name, "GLVEBTC_RBCH(0,0)"); break;
		case I40E_GLVEBTC_RBCL(0,0):
			sprintf(name, "GLVEBTC_RBCL(0,0)"); break;
		case I40E_GLVEBTC_RPCH(0,0):
			sprintf(name, "GLVEBTC_RPCH(0,0)"); break;
		case I40E_GLVEBTC_RPCL(0,0):
			sprintf(name, "GLVEBTC_RPCL(0,0)"); break;
		case I40E_GLVEBTC_TBCH(0,0):
			sprintf(name, "GLVEBTC_TBCH(0,0)"); break;
		case I40E_GLVEBTC_TBCL(0,0):
			sprintf(name, "GLVEBTC_TBCL(0,0)"); break;
		case I40E_GLVEBTC_TPCH(0,0):
			sprintf(name, "GLVEBTC_TPCH(0,0)"); break;
		case I40E_GLVEBTC_TPCL(0,0):
			sprintf(name, "GLVEBTC_TPCL(0,0)"); break;
		case I40E_GLVEBVL_BPCH(0):
			sprintf(name, "GLVEBVL_BPCH(0)"); break;
		case I40E_GLVEBVL_BPCL(0):
			sprintf(name, "GLVEBVL_BPCL(0)"); break;
		case I40E_GLVEBVL_GORCH(0):
			sprintf(name, "GLVEBVL_GORCH(0)"); break;
		case I40E_GLVEBVL_GORCL(0):
			sprintf(name, "GLVEBVL_GORCL(0)"); break;
		case I40E_GLVEBVL_GOTCH(0):
			sprintf(name, "GLVEBVL_GOTCH(0)"); break;
		case I40E_GLVEBVL_GOTCL(0):
			sprintf(name, "GLVEBVL_GOTCL(0)"); break;
		case I40E_GLVEBVL_MPCH(0):
			sprintf(name, "GLVEBVL_MPCH(0)"); break;
		case I40E_GLVEBVL_MPCL(0):
			sprintf(name, "GLVEBVL_MPCL(0)"); break;
		case I40E_GLVEBVL_UPCH(0):
			sprintf(name, "GLVEBVL_UPCH(0)"); break;
		case I40E_GLVEBVL_UPCL(0):
			sprintf(name, "GLVEBVL_UPCL(0)"); break;
		case I40E_GL_MTG_FLU_MSK_H:
			sprintf(name, "GL_MTG_FLU_MSK_H"); break;
		case I40E_GL_SWR_DEF_ACT(0):
			sprintf(name, "GL_SWR_DEF_ACT(0)"); break;
		case I40E_GL_SWR_DEF_ACT_EN(0):
			sprintf(name, "GL_SWR_DEF_ACT_EN(0)"); break;
		case I40E_PRTTSYN_ADJ:
			sprintf(name, "PRTTSYN_ADJ"); break;
		case I40E_PRTTSYN_AUX_0(0):
			sprintf(name, "PRTTSYN_AUX_0(0)"); break;
		case I40E_PRTTSYN_AUX_1(0):
			sprintf(name, "PRTTSYN_AUX_1(0)"); break;
		case I40E_PRTTSYN_CLKO(0):
			sprintf(name, "PRTTSYN_CLKO(0)"); break;
		case I40E_PRTTSYN_CTL0:
			sprintf(name, "PRTTSYN_CTL0"); break;
		case I40E_PRTTSYN_CTL1:
			sprintf(name, "PRTTSYN_CTL1"); break;
		case I40E_PRTTSYN_EVNT_H(0):
			sprintf(name, "PRTTSYN_EVNT_H(0)"); break;
		case I40E_PRTTSYN_EVNT_L(0):
			sprintf(name, "PRTTSYN_EVNT_L(0)"); break;
		case I40E_PRTTSYN_INC_H:
			sprintf(name, "PRTTSYN_INC_H"); break;
		case I40E_PRTTSYN_INC_L:
			sprintf(name, "PRTTSYN_INC_L"); break;
		case I40E_PRTTSYN_RXTIME_H(0):
			sprintf(name, "PRTTSYN_RXTIME_H(0)"); break;
		case I40E_PRTTSYN_RXTIME_L(0):
			sprintf(name, "PRTTSYN_RXTIME_L(0)"); break;
		case I40E_PRTTSYN_STAT_0:
			sprintf(name, "PRTTSYN_STAT_0"); break;
		case I40E_PRTTSYN_STAT_1:
			sprintf(name, "PRTTSYN_STAT_1"); break;
		case I40E_PRTTSYN_TGT_H(0):
			sprintf(name, "PRTTSYN_TGT_H(0)"); break;
		case I40E_PRTTSYN_TGT_L(0):
			sprintf(name, "PRTTSYN_TGT_L(0)"); break;
		case I40E_PRTTSYN_TIME_H:
			sprintf(name, "PRTTSYN_TIME_H"); break;
		case I40E_PRTTSYN_TIME_L:
			sprintf(name, "PRTTSYN_TIME_L"); break;
		case I40E_PRTTSYN_TXTIME_H:
			sprintf(name, "PRTTSYN_TXTIME_H"); break;
		case I40E_PRTTSYN_TXTIME_L:
			sprintf(name, "PRTTSYN_TXTIME_L"); break;
		case I40E_GL_MDET_RX:
			sprintf(name, "GL_MDET_RX"); break;
		case I40E_GL_MDET_TX:
			sprintf(name, "GL_MDET_TX"); break;
		case I40E_PF_MDET_RX:
			sprintf(name, "PF_MDET_RX"); break;
		case I40E_PF_MDET_TX:
			sprintf(name, "PF_MDET_TX"); break;
		case I40E_PF_VT_PFALLOC:
			sprintf(name, "PF_VT_PFALLOC"); break;
		case I40E_VP_MDET_RX(0):
			sprintf(name, "VP_MDET_RX(0)"); break;
		case I40E_VP_MDET_TX(0):
			sprintf(name, "VP_MDET_TX(0)"); break;
		case I40E_GLPM_WUMC:
			sprintf(name, "GLPM_WUMC"); break;
		case I40E_PFPM_APM:
			sprintf(name, "PFPM_APM"); break;
		case I40E_PFPM_FHFT_LENGTH(0):
			sprintf(name, "PFPM_FHFT_LENGTH(0)"); break;
		case I40E_PFPM_WUC:
			sprintf(name, "PFPM_WUC"); break;
		case I40E_PFPM_WUFC:
			sprintf(name, "PFPM_WUFC"); break;
		case I40E_PFPM_WUS:
			sprintf(name, "PFPM_WUS"); break;
		case I40E_PRTPM_FHFHR:
			sprintf(name, "PRTPM_FHFHR"); break;
		case I40E_PRTPM_SAH(0):
			sprintf(name, "PRTPM_SAH(0)"); break;
		case I40E_PRTPM_SAL(0):
			sprintf(name, "PRTPM_SAL(0)"); break;
		default:
			continue;
		}
		printit32(i, name, mem);
	}
}

// vi:ts=4:sw=4:ht=4:
